RustDockerfile

Struct RustDockerfile 

pub struct RustDockerfile<'a> {
    pub chef_image: &'a str,
    pub cargo_chef_dockerfile: Option<&'a str>,
    pub runtime_image: &'a str,
    pub runtime_base_dockerfile: Option<&'a str>,
    pub build_args: &'a BuildArgsRust,
}

Fields

chef_image: &'a str

local or remote image name for the chef image

cargo_chef_dockerfile: Option<&'a str>

content of inlined chef dockerfile

runtime_image: &'a str

local or remote image name for the runtime image

runtime_base_dockerfile: Option<&'a str>

content of inlined runtime dockerfile

build_args: &'a BuildArgsRust