pub struct RustDockerfile<'a> {
pub chef_image: &'a str,
pub cargo_chef_dockerfile: Option<&'a str>,
pub runtime_image: &'a str,
pub runtime_base_dockerfile: Option<&'a str>,
pub build_args: &'a BuildArgsRust,
}Fields
chef_image: &'a strlocal or remote image name for the chef image
cargo_chef_dockerfile: Option<&'a str>content of inlined chef dockerfile
runtime_image: &'a strlocal or remote image name for the runtime image
runtime_base_dockerfile: Option<&'a str>content of inlined runtime dockerfile
build_args: &'a BuildArgsRustTrait Implementations
Sourceimpl<'a> Display for RustDockerfile<'a>
Implement the format!() trait for RustDockerfile
impl<'a> Display for RustDockerfile<'a>
Implement the format!() trait for RustDockerfile
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl<'a> FastWritable for RustDockerfile<'a>
impl<'a> FastWritable for RustDockerfile<'a>
Sourcefn write_into<AskamaW>(
&self,
dest: &mut AskamaW,
values: &dyn Values,
) -> Result<()>
fn write_into<AskamaW>( &self, dest: &mut AskamaW, values: &dyn Values, ) -> Result<()>
Used internally by askama to speed up writing some types.
Sourceimpl<'a> Template for RustDockerfile<'a>
impl<'a> Template for RustDockerfile<'a>
Sourceconst SIZE_HINT: usize = 1008usize
const SIZE_HINT: usize = 1008usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values<AskamaW>(
&self,
__askama_writer: &mut AskamaW,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values<AskamaW>( &self, __askama_writer: &mut AskamaW, __askama_values: &dyn Values, ) -> Result<()>
Renders the template to the given
writer fmt buffer with provided Values.Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it.Sourcefn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
Helper method which allocates a new
String and renders into it with provided Values.Sourcefn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
fn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
Renders the template to the given
writer fmt buffer.Auto Trait Implementations
impl<'a> Freeze for RustDockerfile<'a>
impl<'a> RefUnwindSafe for RustDockerfile<'a>
impl<'a> Send for RustDockerfile<'a>
impl<'a> Sync for RustDockerfile<'a>
impl<'a> Unpin for RustDockerfile<'a>
impl<'a> UnsafeUnpin for RustDockerfile<'a>
impl<'a> UnwindSafe for RustDockerfile<'a>